==> 7.9.4.tar.gz: lib/xWidgetsBase.dart <==
library xwidgetbase;

import 'dart:async';
import 'dart:io';
import 'dart:typed_data';

import 'package:dropdown_search/dropdown_search.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:image_picker/image_picker.dart';
import 'package:collection/collection.dart';

import 'XStylesBase.dart';

part 'XWidgets/XCheckBoxWidget.dart';
part 'XWidgets/XContainerForImage.dart';
part 'XWidgets/XTreeNode.dart';
part 'XWidgets/XDrawer.dart';
part 'XWidgets/XAlertDIalog.dart';

part 'XWidgets/XBTN/XBtnBase.dart';
part 'XWidgets/XBTN/XBtnTakePhoto.dart';
part 'XWidgets/XBTN/XBtnReloader.dart';

part 'XWidgets/XItemsComplexWidgets/XItem.dart';
part 'XWidgets/XItemsComplexWidgets/XContainer.dart';

part 'XWidgets/XTextFormField/XTextFormField.dart';
part 'XWidgets/XTextFormField/XTextFormFieldLogin.dart';
part 'XWidgets/XTextFormField/XTextFormFieldWithLabel.dart';
part 'XWidgets/XTextFormField/XTextFormFieldWithContainer.dart';

part 'XWidgets/XWidgetsForText/XCardForText.dart';
part 'XWidgets/XWidgetsForText/XContainerWithLabel.dart';
part 'XWidgets/XWidgetsForText/XTextWithLabel.dart';

part 'XfXWidgets/XfxElenco.dart';
part 'XfXWidgets/XfxItemForList.dart';
part 'XfXWidgets/XfxScheda.dart';
part 'XfXWidgets/XfxSchedaTapped.dart';
part 'XfXWidgets/XStatefulWidgetBase.dart';

part 'XfXWidgets/XfxElencoWidgets/XColFilter.dart';
part 'XfXWidgets/XfxElencoWidgets/XHeaderWithSorting.dart';
part 'XWidgets/XTextFormField/XTextFormFieldWithDD.dart';

class XSearchBar extends StatelessWidget {
  final Function()? onPressed;
  final TextEditingController? controller;
  final String? labelText;
  final Color? iconColor;
  final Color? borderColor;
  final String? hintText;
  final TextStyle? hintStyle;
  final TextStyle? labelStyle;
  final TextStyle? textStyle;
  final Widget? iconForSearch;
  final Widget? iconForClear;
  final InputBorder? enabledBorder;
  final InputBorder? disabledBorder;
  final InputBorder? border;
  final FocusNode? searchFocus;
  final bool autoFocus;
  final Function(String)? onTextChanged;
  final Function()? onPressedClear;
  final Function()? onPressedSearch;
  final Color? colorOfSearchBox;
  final Color? colorIconForClear;
  final Color? colorIconForSearch;
  final EdgeInsetsGeometry? marginOfSearchBox;
  final EdgeInsetsGeometry? paddingOfContent;
  final double? height;
  late Timer timerSearch;

  final BoxDecoration? decorationOfContainerXSearch;

  XSearchBar({
    this.labelText,
    this.textStyle,
    this.height,
    this.controller,
    this.decorationOfContainerXSearch,
    this.colorIconForClear,
    this.colorIconForSearch,
    this.iconForClear,
    this.onPressedSearch,
    this.onPressed,
    this.iconColor,
    this.borderColor,
    this.hintText,
    this.hintStyle,
    this.labelStyle,
    this.iconForSearch,
    this.enabledBorder,
    this.disabledBorder,
    this.border,
    this.searchFocus,
    this.onTextChanged,
    this.onPressedClear,
    this.colorOfSearchBox,
    this.marginOfSearchBox,
    this.paddingOfContent,
    this.autoFocus = true,
  });
  // @override
  // onInit()
  // {
  //    timerSearch= Timer(Duration(milliseconds: 100), timerSearchHandlerList)
  // }
  // timerSearchHandlerList() {
  //   if (timerSearch != null) timerSearch!.cancel(); //fermo il mio chiamante
  //   if (searchFilter != "") {
  //     setState(() {
  //       filterCurrentForNave = searchFilter;
  //     });
  //   } else if (searchFilter == "") {
  //     setState(() {
  //       filterCurrentForNave = filterAllForNave;
  //     });
  //   }
  // }

  @override
  Widget build(BuildContext context) {
    return Row(
      children: <Widget>[
        Expanded(
          child: Container(
            margin: marginOfSearchBox ?? EdgeInsets.symmetric(vertical: 8),
            color: decorationOfContainerXSearch != null ? null : colorOfSearchBox ?? Colors.transparent,
            decoration: decorationOfContainerXSearch ?? null,
            height: height,
            child: Padding(
              padding: paddingOfContent ?? EdgeInsets.all(8.0),
              child: TextField(
                focusNode: searchFocus,
                autofocus: autoFocus,
                onChanged: onTextChanged,
                controller: controller,
                style: textStyle ?? XStyles.xStyTextForDescr(Colors.black),
                decoration: InputDecoration(
                    suffixIcon: Row(mainAxisAlignment: MainAxisAlignment.end, mainAxisSize: MainAxisSize.min, children: [
                      Container(
                          width: 50,
                          child: IconButton(
                              onPressed: onPressedClear ??
                                  () {
                                    controller!.clear();
                                  },
                              icon: iconForClear ?? Icon(Icons.clear),
                              color: colorIconForClear ?? Colors.black)),
                      iconForSearch == null ? Container() : Container(width: 50, child: IconButton(onPressed: onPressedSearch ?? () {}, icon: iconForSearch ?? Icon(Icons.search), color: colorIconForSearch ?? Colors.black)),
                    ]),
                    labelText: labelText ?? null,
                    hintText: hintText ?? "Cerca",
                    hintStyle: hintStyle ?? XStyles.xStyTextForDescr(Colors.black),
                    labelStyle: labelStyle ?? XStyles.xStyTextForLabel(Colors.black),
                    enabledBorder: enabledBorder ?? OutlineInputBorder(borderSide: BorderSide(color: borderColor ?? Colors.black), borderRadius: BorderRadius.all(Radius.circular(25.0))),
                    disabledBorder: disabledBorder ?? OutlineInputBorder(borderSide: BorderSide(color: borderColor ?? Colors.black), borderRadius: BorderRadius.all(Radius.circular(25.0))),
                    border: border ?? OutlineInputBorder(borderSide: BorderSide(color: borderColor ?? Colors.black), borderRadius: BorderRadius.all(Radius.circular(25.0)))),
              ),
            ),
          ),
        ),
      ],
    );
  }
}

class XCircularProgressIndicator extends StatelessWidget {
  final String? label;
  final IconData? icon;
  XCircularProgressIndicator({
    this.label,
    this.icon,
  });

  @override
  Widget build(BuildContext context) {
    return Center(child: SizedBox(child: CircularProgressIndicator(strokeWidth: 8), height: 200.0, width: 200.0));
  }
}

==> 11.3.0.tar.gz: lib/xWidgetsBase.dart <==
library xwidgetbase;

import 'dart:async';
import 'dart:developer';
import 'dart:io';
import 'package:android_intent_plus/android_intent.dart';
import 'package:android_intent_plus/flag.dart';
import 'package:dropdown_search/dropdown_search.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:getwidget/getwidget.dart';
import 'package:getwidget/components/dropdown/gf_dropdown.dart';
import 'package:image_picker/image_picker.dart';
import 'package:collection/collection.dart';
import 'package:qr_code_scanner/qr_code_scanner.dart';
import 'package:xtoolspackage/xtoolspackage.dart';
import 'package:xwidgetsbase/XfXWidgets/XF_View.dart';
import 'XAzureRest.dart';
import 'package:path_provider/path_provider.dart';

import 'XLibStorage.dart';
import 'XStylesBase.dart';
import 'package:observable/observable.dart' show ObservableList;
import 'package:shared_preferences/shared_preferences.dart';
import 'package:provider/provider.dart';

import 'XfXWidgets/XElenco.dart';
import 'XfXWidgets/XF_Col.dart';
import 'XfXWidgets/XF_DataItem.dart';

part 'XWidgets/DaRivedere/XCheckBoxWidget.dart';
part 'XWidgets/DaRivedere/XTreeNode.dart';

part 'XWidgets/XViewWidgets/XContainerForImage.dart';
part 'XWidgets/XViewWidgets/XAlertDIalog.dart';
part 'XWidgets/XViewWidgets/XDashboardCard.dart';

part 'XWidgets/XWidgetsForContentOfPage/XDrawer.dart';
part 'XWidgets/XWidgetsForContentOfPage/XAppBar.dart';
part 'XWidgets/XWidgetsForContentOfPage/XBottomNavigationBarItem.dart';
part 'XWidgets/XWidgetsForContentOfPage/XDismissKeyBoardWidget.dart';

part 'XWidgets/XBTN/XBtnBase.dart';
part 'XWidgets/XBTN/XBtnTakePhoto.dart';
part 'XWidgets/XBTN/XBtnReloader.dart';
part 'XWidgets/XBTN/XBtnBaseForTheme.dart';

part 'XWidgets/XItemsComplexWidgets/XItem.dart';
part 'XWidgets/XItemsComplexWidgets/XContainer.dart';
part 'XWidgets/XItemsComplexWidgets/XConcatenatedWidget.dart';
part 'XWidgets/XItemsComplexWidgets/XBarCodeScanner.dart';

part 'XWidgets/XTextFormField/XTextFormField.dart';
part 'XWidgets/XTextFormField/XTextFormFieldLogin.dart';
part 'XWidgets/XTextFormField/XTextFormFieldWithLabel.dart';
part 'XWidgets/XTextFormField/XTextFormFieldWithContainer.dart';
part 'XWidgets/XTextFormField/XTextFormFieldWithDD.dart';

part 'XWidgets/XWidgetsForText/XCardForText.dart';
part 'XWidgets/XWidgetsForText/XContainerWithLabel.dart';
part 'XWidgets/XWidgetsForText/XTextWithLabel.dart';

part 'XWidgets/XDD/XDropSearch.dart';
part 'XWidgets/XDD/XDDGeneric.dart';
part 'XWidgets/XDD/XDDGenericWithType.dart';

part 'XfXWidgets/XfxItemForList.dart';
part 'XfXWidgets/XfxScheda.dart';
part 'XfXWidgets/XfxSchedaTapped.dart';
part 'XfXWidgets/XStatefulWidgetBase.dart';
part 'XfXWidgets/XElencoItem.dart';
part 'XfXWidgets/XfxElenco.dart';
part 'XfXWidgets/XfxUpdater.dart';

part 'XfXWidgets/XfxElencoWidgets/XColFilter.dart';
part 'XfXWidgets/XfxElencoWidgets/XHeaderWithSorting.dart';
part 'XApp/XApp.dart';
part 'XApp/XAppData_Base.dart';
part 'XApp/XMainPage_Base.dart';
part 'XApp/XfxArea.dart';
part 'XApp/XfxMenu.dart';
//part 'XApp/';

class XSearchBar extends StatelessWidget {
  final Function()? onPressed;
  final TextEditingController? controller;
  final String? labelText;
  final Color? iconColor;
  final Color? borderColor;
  final String? hintText;
  final TextStyle? hintStyle;
  final TextStyle? labelStyle;
  final TextStyle? textStyle;
  final Widget? iconForSearch;
  final Widget? iconForClear;
  final InputBorder? enabledBorder;
  final InputBorder? disabledBorder;
  final InputBorder? border;
  final FocusNode? searchFocus;
  final bool autoFocus;
  final Function(String)? onTextChanged;
  final Function()? onPressedClear;
  final Function()? onPressedSearch;
  final Color? colorOfSearchBox;
  final Color? colorIconForClear;
  final Color? colorIconForSearch;
  final EdgeInsetsGeometry? marginOfSearchBox;
  final EdgeInsetsGeometry? paddingOfContent;
  final double? height;
  late Timer timerSearch;

  final BoxDecoration? decorationOfContainerXSearch;

  XSearchBar({
    this.labelText,
    this.textStyle,
    this.height,
    this.controller,
    this.decorationOfContainerXSearch,
    this.colorIconForClear,
    this.colorIconForSearch,
    this.iconForClear,
    this.onPressedSearch,
    this.onPressed,
    this.iconColor,
    this.borderColor,
    this.hintText,
    this.hintStyle,
    this.labelStyle,
    this.iconForSearch,
    this.enabledBorder,
    this.disabledBorder,
    this.border,
    this.searchFocus,
    this.onTextChanged,
    this.onPressedClear,
    this.colorOfSearchBox,
    this.marginOfSearchBox,
    this.paddingOfContent,
    this.autoFocus = true,
  });
  // @override
  // onInit()
  // {
  //    timerSearch= Timer(Duration(milliseconds: 100), timerSearchHandlerList)
  // }
  // timerSearchHandlerList() {
  //   if (timerSearch != null) timerSearch!.cancel(); //fermo il mio chiamante
  //   if (searchFilter != "") {
  //     setState(() {
  //       filterCurrentForNave = searchFilter;
  //     });
  //   } else if (searchFilter == "") {
  //     setState(() {
  //       filterCurrentForNave = filterAllForNave;
  //     });
  //   }
  // }

  @override
  Widget build(BuildContext context) {
    return Row(
      children: <Widget>[
        Expanded(
          child: Container(
            margin: marginOfSearchBox ?? EdgeInsets.symmetric(vertical: 8),
            color: decorationOfContainerXSearch != null ? null : colorOfSearchBox ?? Colors.transparent,
            decoration: decorationOfContainerXSearch ?? null,
            height: height,
            child: Padding(
              padding: paddingOfContent ?? EdgeInsets.all(8.0),
              child: TextField(
                focusNode: searchFocus,
                autofocus: autoFocus,
                onChanged: onTextChanged,
                controller: controller,
                style: textStyle ?? XStyles.xStyTextForDescr(Colors.black),
                decoration: InputDecoration(
                    suffixIcon: Row(mainAxisAlignment: MainAxisAlignment.end, mainAxisSize: MainAxisSize.min, children: [
                      controller!.text != ""
                          ? Container(
                              width: 50,
                              child: IconButton(
                                  onPressed: onPressedClear ??
                                      () {
                                        controller!.clear();
                                      },
                                  icon: iconForClear ?? Icon(Icons.clear),
                                  color: colorIconForClear ?? Colors.black))
                          : Container(),
                      iconForSearch == null ? Container() : Container(width: 50, child: IconButton(onPressed: onPressedSearch ?? () {}, icon: iconForSearch ?? Icon(Icons.search), color: colorIconForSearch ?? Colors.black)),
                    ]),
                    labelText: labelText ?? null,
                    hintText: hintText ?? "Cerca",
                    hintStyle: hintStyle ?? XStyles.xStyTextForDescr(Colors.black),
                    labelStyle: labelStyle ?? XStyles.xStyTextForLabel(Colors.black),
                    enabledBorder: enabledBorder ?? OutlineInputBorder(borderSide: BorderSide(color: borderColor ?? Colors.black), borderRadius: BorderRadius.all(Radius.circular(25.0))),
                    disabledBorder: disabledBorder ?? OutlineInputBorder(borderSide: BorderSide(color: borderColor ?? Colors.black), borderRadius: BorderRadius.all(Radius.circular(25.0))),
                    border: border ?? OutlineInputBorder(borderSide: BorderSide(color: borderColor ?? Colors.black), borderRadius: BorderRadius.all(Radius.circular(25.0)))),
              ),
            ),
          ),
        ),
      ],
    );
  }
}

class XCircularProgressIndicator extends StatelessWidget {
  final String? label;
  final IconData? icon;
  XCircularProgressIndicator({
    this.label,
    this.icon,
  });

  @override
  Widget build(BuildContext context) {
    return Center(child: SizedBox(child: CircularProgressIndicator(strokeWidth: 8), height: 200.0, width: 200.0));
  }
}

alertDialogForPop(BuildContext context, Function()? onPressedYes, {String? titleText, Function()? onPressedNo, double? heightAlertDialog}) {
  return showDialog(
      context: context,
      builder: (context) {
        return XAlertDialog(
          title_TextAlign: TextAlign.center,
          height: heightAlertDialog ?? 35,
          title_Style: XStyles.xStyTextForSubLabel(),
          title_Text: titleText ?? "Vuoi salvare le modifiche fatte?",
          btnYES_label: "SI",
          btnNO_label: "NO",
          btnYES_Labelcolor: XColors.done,
          btnNO_Labelcolor: Colors.red,
          btnYES_OnPressed: () {
            Navigator.pop(context);
            onPressedYes?.call();
          },
          btnNO_OnPressed: onPressedNo ?? () => Navigator.pop(context),
        );
      });
}

String? validatorBL(dynamic value) {
  if (value == null) return "Compila il campo";
  if (value is DateTime) {
    return null;
  } else if (value.isEmpty) {
    return "Compila il campo";
  }
}
